@@ -3,7 +3,12 @@
 #############################################################################
 
 get.checkerboard1 <- function(occ, env, bg.coords, aggregation.factor){
-
+  
+  occ <- as.data.frame(occ)
+  rownames(occ) <- 1:nrow(occ)
+  bg.coords <- as.data.frame(bg.coords)
+  rownames(bg.coords) <- 1:nrow(bg.coords)
+    
 	grid <- aggregate(env[[1]], fact=aggregation.factor[1])
 	w <- gridSample(occ, grid, n=1e6, chess='white')
 	b <- gridSample(occ, grid, n=1e6, chess='black')
